<?php declare(strict_types=1);

namespace Sit\Creditpass\Console\Command;

use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepositoryInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Helper\Table;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class ConfigurationListCommand extends Command {

    private $configurationRepository;

    public function __construct(
        EntityRepositoryInterface $configurationRepository,
        string $name = null) {

        parent::__construct($name);
        $this->configurationRepository = $configurationRepository;
    }

    protected function configure() {

        $this->setName("cp_configuration:list")->setDescription("List all cp_configurations");
    }

    protected function execute(InputInterface $input, OutputInterface $output ) {

        $searchResult = $this->configurationRepository->search(new Criteria(), Context::createDefaultContext());

        $table = new Table($output);
        $table->setHeaders(['UUID', 'Name']);

        foreach ($searchResult->getEntities() as $configuration) {
            $table->addRow([
                $configuration->getId(),
                $configuration->getName()
            ]);
        }

        $table->render();
    }
}
