<?php

declare(strict_types=1);

namespace Sit\Creditpass\Controllers\Administration;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Shopware\Core\Framework\Routing\Annotation\RouteScope;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @RouteScope(scopes={"api"})
 */
class SitCreditpassCredentialsController extends AbstractController {

    /**
     * @Route("/api/_action/sit-creditpass-credentials/{user}/{password}", name="api.action.sit.creditpass.credentials", methods={"GET"})
     */
    public function checkCreditpassCredentials(string $user, string $password): JsonResponse {

        // Create request xml
        $request =  '<?xml version="1.0" encoding="UTF-8" ?>' .
                    '<REQUEST>' .
                        '<CUSTOMER>' .
                        '<AUTH_ID>' . $user . '</AUTH_ID>' .
                        '<AUTH_PW>' . $password . '</AUTH_PW>' .
                        '</CUSTOMER>' .
                        '<PROCESS>' .
                            '<TA_TYPE>10</TA_TYPE>' .
                        '</PROCESS>' .
                    '</REQUEST>';

// echo "<pre>request:<br>";
// echo $request;
// echo "</pre>";

        $response = $this->postRequest('https://secure.creditpass.de/atgw/authorize.cfm', $request);

        $xml = simplexml_load_string($response['content']);

// echo "<pre>response:<br>";
// echo $xml;
// echo "</pre>";

        $result = (String) $xml->PROCESS->ANSWER_CODE[0];

        return new JsonResponse(['result' => $result]);
    }

    private function postRequest($sURL, $sMessage = ""): array {

        $postData = array();
        $postData["Reqpk"] = $sMessage;

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_URL, $sURL);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postData) );
        curl_setopt($ch, CURLOPT_HEADER, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);

        // Set curl options
        $response = curl_exec($ch);
        if ($response === FALSE) {

            $error = curl_error($ch);
            return array(
                'status' => 'err',
                'error' => $error
            );
        }

        // Get header and body
        $header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
        $result = substr($response, $header_size);

        // Kein Fehler
        curl_close($ch);

        // return as structured array:
        return array(
            'status' => 'ok',
            'content' => $result
        );
    }
}
