<?php declare(strict_types=1);

namespace Sit\Creditpass\Core\Content\Check;

use Shopware\Core\Checkout\Customer\CustomerDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\DateTimeField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToOneAssociationField;
use Sit\Creditpass\Core\Content\Configuration\ConfigurationDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\LongTextField;

class CheckDefinition extends EntityDefinition
{
    public const ENTITY_NAME = "cp_check";

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new LongTextField('request', 'request')),
            (new StringField('requestFirstname', 'requestFirstname')),
            (new StringField('requestLastname', 'requestLastname')),
            (new StringField('requestStreet', 'requestStreet')),
            (new StringField('requestCity', 'requestCity')),
            (new DateTimeField('requestDate', 'requestDate')),
            (new StringField('requestPurchaseType', 'requestPurchaseType')),
            (new StringField('requestHash', 'requestHash')),
            (new LongTextField('response', 'response')),
            (new StringField('responseResult', 'responseResult')),

            (new StringField('customerId', 'customerId')),
            (new FkField('customer_id', 'customerId', CustomerDefinition::class))->addFlags(new Required()),
            new ManyToOneAssociationField('customer', 'customer_id', CustomerDefinition::class, 'id', false),

            (new StringField('configurationId', 'configurationId')),
            (new FkField('configuration_id', 'configurationId', ConfigurationDefinition::class))->addFlags(new Required()),
            new ManyToOneAssociationField('configuration', 'configuration_id', ConfigurationDefinition::class, 'id', false),

            new CreatedAtField(),
            new UpdatedAtField()
        ]);
    }

    public function getEntityClass(): string {

        return CheckEntity::class;
    }

    public function getCollectionClass(): string {

        return CheckCollection::class;
    }
}
