<?php declare(strict_types=1);

namespace Sit\Creditpass\Core\Content\Configuration;

use Shopware\Core\Checkout\Customer\Aggregate\CustomerGroup\CustomerGroupDefinition;
use Shopware\Core\Checkout\Payment\PaymentMethodDefinition;
use Shopware\Core\Content\Category\CategoryDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\BoolField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IntField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Sit\Creditpass\Core\Content\Configuration\Aggregate\ConfigurationCategory\ConfigurationCategoryDefinition;
use Sit\Creditpass\Core\Content\Configuration\Aggregate\ConfigurationPaymentMethod\ConfigurationPaymentMethodDefinition;
use Sit\Creditpass\Core\Content\Configuration\Aggregate\ConfigurationCustomerGroupWhitelist\ConfigurationCustomerGroupWhitelistDefinition;
use Sit\Creditpass\Core\Content\Configuration\Aggregate\ConfigurationCustomerGroup\ConfigurationCustomerGroupDefinition;

class ConfigurationDefinition extends EntityDefinition
{
    public const ENTITY_NAME = "cp_configuration";

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new StringField('name', 'name')),
            (new BoolField('isActive', 'isActive')),
            (new IntField('amountFrom', 'amountFrom'))->addFlags(new Required()),
            (new IntField('amountTo', 'amountTo'))->addFlags(new Required()),
            (new IntField('repeatAfter', 'repeatAfter'))->addFlags(new Required()),
            (new StringField('errormessage', 'errormessage')),
            (new StringField('creditpassUser', 'creditpassUser'))->addFlags(new Required()),
            (new StringField('creditpassPassword', 'creditpassPassword'))->addFlags(new Required()),
            (new StringField('purchaseType', 'purchaseType'))->addFlags(new Required()),
            (new BoolField('isAbortOnFail', 'isAbortOnFail')),

            (new ManyToManyAssociationField('payments', PaymentMethodDefinition::class, ConfigurationPaymentMethodDefinition::class, 'configuration_id', 'payment_method_id')),
            (new ManyToManyAssociationField('categories', CategoryDefinition::class, ConfigurationCategoryDefinition::class, 'configuration_id', 'category_id')),
            (new ManyToManyAssociationField('groups', CustomerGroupDefinition::class, ConfigurationCustomerGroupDefinition::class, 'configuration_id', 'customer_group_id')),
            (new ManyToManyAssociationField('wlgroups', CustomerGroupDefinition::class, ConfigurationCustomerGroupWhitelistDefinition::class, 'configuration_id', 'customer_group_id')),

            new CreatedAtField(),
            new UpdatedAtField()
        ]);
    }

    public function getEntityClass(): string {

        return ConfigurationEntity::class;
    }

    public function getCollectionClass(): string {

        return ConfigurationCollection::class;
    }
}
