import template from './cp-check-detail.html.twig';
import './cp-check-detail.scss';

const { Component, Mixin } = Shopware;
const { Criteria } = Shopware.Data;

Component.register('cp-check-detail', {
    template,

    inject: [
        'repositoryFactory'
    ],

    mixins: [
        Mixin.getByName('notification')
    ],

    data() {
        return {
            isLoading: null,
            isSaveSuccessful: false,
            cpCheck: null,
        };
    },

    metaInfo() {
        return {
            title: this.$createTitle()
        };
    },

    computed: {

        repository() {
            return this.repositoryFactory.create('cp_check');
        },

        customerCriteria() {
            const criteria = new Criteria(1, 25);

            criteria.addAssociation('defaultBillingAddress.country');

            return criteria;
        },

        configurationCriteria() {
            const criteria = new Criteria(1, 25);
            return criteria;
        }
    },

    watch: {
        '$route.params.id'() {
            this.createdComponent();
        }
    },

    created() {
        this.createdComponent();
    },

    methods: {

        createdComponent() {

            if (this.$route.params.id) {
                this.loadEntityData();
            }
        },

        loadEntityData() {

            this.isLoading = true;

            this.repository.get(this.$route.params.id, Shopware.Context.api).then((entity) => {

                this.cpCheck = entity;
                this.isLoading = false;

            });
        },

        onSave() {

            this.isSaveSuccessful = false;




            this.repository.save(this.cpCheck, Shopware.Context.api).then(() => {

                this.isSaveSuccessful = true;

            }).catch((exception) => {

                this.isSaveSuccessful = false;

                this.createNotificationError({
                    title: this.$t('cp-trans.cp-check-detail.errorTitle'),
                    message: exception
                });
            });
        },

        onSaveFinish() {
            this.loadEntityData();
            this.isSaveSuccessful = false;
        }
    }
});
