<?php declare(strict_types=1);

namespace Sit\Creditpass;

use Doctrine\DBAL\Connection;
use Shopware\Core\Framework\Plugin;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Shopware\Core\Framework\Plugin\Context\UninstallContext;

class SitCreditpass extends Plugin {

    // LIVE MODE
    var $licenseUrl = "https://www.shopmodul24.de/SITModuleFramework/core/SITCoreConfigurator.php";

    /**
     * @param ContainerBuilder $container
     */
    public function build( ContainerBuilder $container ): void {

        parent::build( $container );

        $this->loadAboInfo("SIT-Creditpass");
    }

    /**
     * @param $moduleTitle
     */
    private function loadAboInfo($moduleTitle) {

        $publicKey = $this->createPublicKey($moduleTitle);
        $url = $this->licenseUrl;

        // Check curl
        if ( function_exists('curl_version') ) {

            $postData = "publicKey=" . urlencode($publicKey) . "&request=info";

            $ch = curl_init();

            $timeout = 5;
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $postData );
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_VERBOSE, 1);
            curl_setopt($ch, CURLOPT_HEADER, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);

            //execute post
            curl_exec($ch);

            //close connection
            curl_close($ch);
        }
    }

    /**
     * @param $moduleTitle
     * @return string
     */
    private function createPublicKey($moduleTitle): string {

        $sShopUrl = "";
        if ( ! empty($_SERVER["SERVER_NAME"]) ) {
            $sShopUrl = $_SERVER["SERVER_NAME"];
        }
        else if ( ! empty($_SERVER["SERVER_ADDR"]) ) {
            $sShopUrl = $_SERVER["SERVER_ADDR"];
        }

        $documentPath = strtolower(__FILE__);

        // Create pk
        $publicKey = base64_encode($sShopUrl . "|_|" . $documentPath . "|_|" . $moduleTitle);

        return $publicKey;
    }

    /**
     * {@inheritdoc}
     */
    public function uninstall(UninstallContext $uninstallContext): void {

        /** @var Connection $connection */
        $connection = $this->container->get(Connection::class);

        if ( !$uninstallContext->keepUserData() ) {
            $connection->executeStatement('
                DROP TABLE IF EXISTS `cp_check`;
                DROP TABLE IF EXISTS `cp_configuration`;
                DROP TABLE IF EXISTS `cp_configuration_category`;
                DROP TABLE IF EXISTS `cp_configuration_payment_method`;
                DROP TABLE IF EXISTS `cp_configuration_customer_group`;
                DROP TABLE IF EXISTS `cp_configuration_customer_group_whitelist`;
            ');
        }
    }
}
